#//-----------------------------------------------
#//TUSB-INS16O用Pythonサンプルプログラム
#// 処理関数等
#//
#//2024_05_01　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------

import tkinter as tk
import tkinter.ttk as ttk
from tkinter import messagebox

def ShowInfo(str):
    """文字列を表示する"""
    messagebox.showinfo("",str)

def GetLabel(master,text,relx,rely):
    """ラベルを作成する
    
    arguments:
    master      ----    配置ペアレント
    text        ----    表示する文字列
    relx        ----    X座標相対位置(左端)
    rely        ----    Y座標相対位置(上下中央)

    returns:
    Label       ----    生成されたラベルインスタンス
    """
    label = tk.Label(master,text=text)
    label.place(relx=relx,rely=rely,anchor=tk.W)
    return label

def GetChkBoxCom(master,text,relx,rely,val,command=None):
    """チェックボックスを生成する イベントハンドラ設定付
    
    arguments:
    master      ----    配置ペアレント
    text        ----    表示する文字列
    relx        ----    X座標相対位置(左端)
    rely        ----    Y座標相対位置(上下中央)
    val         ----    variableを対応させるwidget変数(例 BooleanVar())
    command     ----    ボタンが押された時に呼び出されるハンドラ関数

    returns:
    Checkbutton ----    生成されたチェックボックスのインスタンス
    """
    chkbox = tk.Checkbutton(master,text=text,variable=val,command=command)
    chkbox.place(relx=relx,rely=rely,anchor=tk.W)
    return chkbox

def GetButton(master,text,command,relw,relx,rely):
    """ボタンを作成する
    
    arguments:
    master      ----    配置ペアレント
    text        ----    ボタンに表示する文字列
    command     ----    ボタンが押された時に呼び出されるハンドラ関数
    relw        ----    表示幅(相対値)
    relx        ----    X座標相対位置(左右中央)
    rely        ----    Y座標相対位置(上下中央)

    returns:
    Button      ----    生成されたボタンインスタンス
    """
    button = tk.Button(master,text=text,command=command)
    button.place(relwidth=relw,relx=relx,rely=rely,anchor=tk.CENTER)
    return button

def GetComboBox(master,value,relw,relx,rely,command=None):
    """コンボボックスを作成する
    
    arguments:
    master      ----    配置ペアレント
    value       ----    コンボボックスに設定するデータリスト(又はタプル)
    relw        ----    表示幅(相対値)
    relx        ----    X座標相対位置(左端)
    rely        ----    Y座標相対位置(上下中央)
    command     ----    選択値が変更した時に呼び出される関数(引数としてイベントが渡される)

    returns:
    Combobox    ----    生成されたコンボボックスインスタンス
    """
    combobox = ttk.Combobox(master,value=value,state="readonly")
    combobox.bind("<<ComboboxSelected>>",command)
    combobox.place(relwidth=relw,relx=relx,rely=rely,anchor=tk.W)
    combobox.current(0)
    return combobox

def GenTkVarList(N,cls,initval):
    """Tkinter Var list generator with value initialize
    
    arguments:
    N           ----    list length
    cls         ----    tkinter variable class
    initval     ----    initial value
    
    returns:
    list        ----    generated list
    """
    ret = list()
    for i in range(N):
        ret.append(cls(value=initval))
    return ret
