#//-----------------------------------------------
#//TUSB-INS16O用ドライバアクセス用API
#//Python 用モジュール
#//
#//2024_05_01　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------

from ctypes import *

tusbinsodll = cdll.LoadLibrary("TUSBINSO.DLL")

tusbinsodll.Tusbins16o_Device_Open.restype = c_short
tusbinsodll.Tusbins16o_Device_Open.argtypes = (c_short,)
tusbinsodll.Tusbins16o_Device_Close.restype = None
tusbinsodll.Tusbins16o_Device_Close.argtypes = (c_short,)
tusbinsodll.Tusbins16o_Write.restype = c_short
tusbinsodll.Tusbins16o_Write.argtypes = (c_short,c_uint)

#######  support functions (don not call directry from user codes)

def isint(n):
    return type(n) is int

def IsInRange(Val,Min,Max):
    if(isint(Val) == False ):   return False
    elif(Val < Min):            return False
    elif(Val > Max):            return False
    else:                       return True

def IsValidId(DevId):
    return IsInRange(DevId,0,15)

# def functions ------------------------------------

def Tusbins16o_Device_Open(DevId):
    """Open Device Connection
    
    Arguments:
    DevId           ----    DevIce ID 0~15
    
    Returns:
    int             ----    Result code
    """
    if(not IsValidId(DevId)):return 1
    return tusbinsodll.Tusbins16o_Device_Open(DevId)

def Tusbins16o_Device_Close(DevId):
    """Close Device Connection

    Arguments:
    DevId           ----    Device ID 0~15

    Returns:
    None
    """
    if(not IsValidId(DevId)):return 2
    tusbinsodll.Tusbins16o_Device_Close(DevId)

def Tusbins16o_Write(DevId,Data):
    """Write Output Resistor
    
    Arguments:
    DevId           ----    Device ID 0~15
    Deta            ----    Output Data bit pattern 0~65535

    Returns:
    int             ----    Result code
    """
    if(not IsValidId(DevId)):return 2
    if(not IsInRange(Data,0,65535)):return 2
    return tusbinsodll.Tusbins16o_Write(DevId,Data)

#戻り値用エラーメッセージ(オープン関数のみ)
OpenErrStrDic = {
            0:"正常終了しました",
            1:"ID番号が不正です",
            3:"すでにデバイスはオープンされています",
            4:"接続されている台数が多すぎます",
            5:"オープンできませんでした",
            6:"デバイスがみつかりません",
}
def GetOpenErrMessage(retcode):
    if( retcode in OpenErrStrDic):
        return OpenErrStrDic[retcode]
    else:
        return "不明なエラーです"

#戻り値用エラーメッセージ
ErrStrDic = {
            0:"正常終了しました",
            1:"このデバイスはオープンされていません",
            2:"失敗しました",
}
def GetErrMessage(retcode):
    if( retcode in ErrStrDic):
        return ErrStrDic[retcode]
    else:
        return "不明なエラーです"
