#//-----------------------------------------------
#//TUSB-INS16O用サンプルプログラム
#//Python 用モジュール
#//
#//2024_05_01　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------
import TUSBINSO

from SpFuncs import *

from functools import partial

DevId = None            # 開いているデバイスのID

# Sub Functions -----------------------------

# Widgetの表示を設定する
# stat -> 'Close' , 'Open'
def WidgetState(stat):
    """Widgetの表示を設定する
    
    Arguments:
        stat        ----    設定状態 'Close' or 'Open'
    """
    EnClose = tk.NORMAL if( stat == 'Close' ) else tk.DISABLED
    EnOpen = tk.NORMAL if( stat == 'Open' ) else tk.DISABLED
    for bit in range(16):OutputChk[bit]['state'] = EnOpen
    IDCmbb['state'] = EnClose
    OpenBtn['state'] = EnClose
    CloseBtn['state'] = EnOpen
    if stat != 'Close' :
        form.protocol('WM_DELETE_WINDOW',lambda: 'pass' )
    else :
        form.protocol('WM_DELETE_WINDOW',lambda: form.destroy())

def Output_on():
    """出力設定(チェック)が変化"""
    Data = 0
    for bit in range(16):Data += (1<<bit) if OutputVal[bit].get() else 0
    ret = TUSBINSO.Tusbins16o_Write(DevId,Data)
    if ret != 0:
        ShowInfo(TUSBINSO.GetErrMessage(ret))

def OpenBtn_on():
    """オープンボタン押下"""
    global DevId
    DevId = IDCmbb.current()
    ret = TUSBINSO.Tusbins16o_Device_Open(DevId)
    if ret ==0:
        WidgetState('Open')
        Output_on()
    else:
        ShowInfo(TUSBINSO.GetOpenErrMessage(ret))

def CloseBtn_on():
    """クローズボタン押下"""
    TUSBINSO.Tusbins16o_Device_Close(DevId)
    WidgetState('Close')

# form generation ---------------------------
form  = tk.Tk()
form.geometry('250x501')
form.title('TUSB-INS16O Sample Program')
form.attributes("-toolwindow",True)

# 見出しラベル
GetLabel(form,"Bit",0.2,0.05)
GetLabel(form,"Output",0.4,0.05)

# ビット毎項目
OutputChk = list()
OutputVal = GenTkVarList(16,tk.BooleanVar,False)
bypit = 0.044   # 行ピッチ
for bit in range(16):
    ly = 0.1+bypit*bit
    GetLabel(form,str(bit),0.2,ly)
    OutputChk.append(GetChkBoxCom(form,"",0.4,ly,OutputVal[bit],partial(Output_on)))

#ID open close
IDList = [str(i) for i in range(16)]
GetLabel(form,"ID",0.1,0.85)
IDCmbb = GetComboBox(form,IDList,0.2,0.2,0.85)
OpenBtn = GetButton(form,"DevOpen",OpenBtn_on,0.3,0.25,0.93)
CloseBtn = GetButton(form,"DevClose",CloseBtn_on,0.3,0.7,0.93)

# Start
WidgetState('Close')
form.mainloop()
